==> qtjambi-qt3danimation-jre8-5.15.5-sources.jar: io/qt/qt3d/animation/QAbstractAnimationClip.java <==
package io.qt.qt3d.animation;


/**
 * <p>The base class for types providing key frame animation data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qabstractanimationclip.html">Qt3DAnimation::QAbstractAnimationClip</a></p>
 */
public class QAbstractAnimationClip extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractAnimationClip.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qabstractanimationclip.html#duration-prop">Qt3DAnimation::QAbstractAnimationClip::durationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="duration")
    public final Signal1<@io.qt.QtPrimitiveType Float> durationChanged = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qabstractanimationclip.html#duration-prop">Qt3DAnimation::QAbstractAnimationClip::duration()const</a></p>
     */
    @io.qt.QtPropertyReader(name="duration")
    @io.qt.QtUninvokable
    public final float duration(){
        return duration_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float duration_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractAnimationClip(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3danimation-jre8-6.3.0-sources.jar: io/qt/qt3d/animation/QAbstractAnimationClip.java <==
package io.qt.qt3d.animation;


/**
 * <p>The base class for types providing key frame animation data</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qabstractanimationclip.html">Qt3DAnimation::QAbstractAnimationClip</a></p>
 */
public class QAbstractAnimationClip extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractAnimationClip.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qabstractanimationclip.html#duration-prop">Qt3DAnimation::QAbstractAnimationClip::durationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="duration")
    public final Signal1<@io.qt.QtPrimitiveType Float> durationChanged = new Signal1<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qabstractanimationclip.html#duration-prop">Qt3DAnimation::QAbstractAnimationClip::duration()const</a></p>
     */
    @io.qt.QtPropertyReader(name="duration")
    @io.qt.QtUninvokable
    public final float duration(){
        return duration_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float duration_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractAnimationClip(QPrivateConstructor p) { super(p); } 
    
}
